@@ -28,7 +28,7 @@ class Resource(ClassRecord):
             ],
             use_alias=True,
         )
-        self.service_name = service_name
+        self.service_name: ServiceName = service_name
         self.collections: List[Collection] = []
 
     @property
@@ -45,7 +45,7 @@ class Resource(ClassRecord):
         """
         return (
             "[Show boto3 documentation]"
-            f"({self.boto3_doc_link})"
+            f"({self.boto3_doc_link})\n"
             "[Show boto3-stubs documentation]"
             f"({self.service_name.get_doc_link('service_resource', self.name)})"
         )
